#ifndef QT_FEATURES__3DRender_src_render_qt3drender_config_h_H
#define QT_FEATURES__3DRender_src_render_qt3drender_config_h_H

#define QT_FEATURE_qt3d_opengl_renderer 1

#define QT_FEATURE_qt3d_rhi_renderer 1

#define QT_FEATURE_qt3d_vulkan 1


#endif // QT_FEATURES__3DRender_src_render_qt3drender_config_h_H
